@@ -32,10 +32,19 @@ class ParseError(Exception):
     '''
     Execption describing a parse error.
     '''
+    @apply
 
-    def __init__(self, filename, lineno, message = _('Malformed configuration file')):
-        message = '%s:%d: %s' % (filename, lineno, message)
-        super(ParseError, self).__init__(message)
+    def message():
+        def get(self):
+            return self._message
+
+        def set(self, value):
+            self._message = value
+
+        return property(get, set)
+
+    def __init__(self, filename, lineno, msg = _('Malformed configuration file')):
+        self.message = '%s:%d: %s' % (filename, lineno, msg)
 
 class Receiver(object):
     '''
@@ -288,6 +297,8 @@ class RemotesDatabase(object):
         Reads remote configurations from tarball.
         '''
 
+        return False
+
         if not os.path.isfile(path):
             return False
 
@@ -835,7 +846,7 @@ class KeyListener(gobject.GObject):
             tuple()),
     }
 
-    def __init__(self, socket_name='/dev/lircd'):
+    def __init__(self, socket_name=config.LIRCD_SOCKET):
         # pylint: disable-msg=E1002
         super(KeyListener, self).__init__()
 
@@ -1011,6 +1022,7 @@ class HardwareConfParser(object):
             key, value = tokens
 
             value = value.strip('"') # Remove quotes
+            value = ''.join(value.split('\\')) # Remove escaping
             self.__values[key] = value
 
     def __getitem__(self, key):
